@@ -3,4 +3,5 @@
 #[macro_use]
 extern crate lazy_static;
 
-mod alloc;
+pub mod pages;
+pub mod alloc;
